@@ -20,6 +20,8 @@
 // We don't want i18n to be expanded to i18nd here
 #undef TRANSLATION_DOMAIN
 
+#include <cstdlib>
+
 #include <QDebug>
 #include <QMutexLocker>
 #include <QStringList>
@@ -31,9 +33,10 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QLibrary>
+#include <QPluginLoader>
 #include <QDir>
 #include <QCoreApplication>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 
 #include <common_helpers_p.h>
 #include <kcatalog_p.h>
@@ -49,7 +52,7 @@ static QString shortenMessage(const QString &str)
     if (str.length() <= maxlen) {
         return str;
     } else {
-        return str.left(maxlen).append(QLatin1String("..."));
+        return str.leftRef(maxlen) + QLatin1String("...");
     }
 }
 
@@ -224,6 +227,15 @@ class KLocalizedStringPrivate
                                       const QString &language);
 
     static void loadTranscript();
+
+    void checkNumber(pluraln a)
+    {
+        if (!plural.isEmpty() && !numberSet) {
+            number = a;
+            numberSet = true;
+            numberOrdinal = arguments.size();
+        }
+    }
 };
 
 typedef QHash<QString, KCatalog *> KCatalogPtrHash;
@@ -247,7 +259,7 @@ public:
     const QChar scriptVachar;
 
     const QString scriptDir;
-    QHash<QString, QStringList> scriptModules;
+    QHash<QString, QList<QByteArray> > scriptModules;
     QList<QStringList> scriptModulesToLoad;
 
     bool loadTranscriptCalled;
@@ -270,18 +282,18 @@ KLocalizedStringPrivateStatics::KLocalizedStringPrivateStatics()
     : catalogs()
     , languages()
 
-    , ourDomain("ki18n")
+    , ourDomain(QByteArrayLiteral("ki18n5"))
     , applicationDomain()
-    , codeLanguage(QLatin1String("en_US"))
+    , codeLanguage(QStringLiteral("en_US"))
     , localeLanguages()
 
-    , theFence(QLatin1String("|/|"))
-    , startInterp(QLatin1String("$["))
-    , endInterp(QLatin1String("]"))
+    , theFence(QStringLiteral("|/|"))
+    , startInterp(QStringLiteral("$["))
+    , endInterp(QStringLiteral("]"))
     , scriptPlchar(QLatin1Char('%'))
     , scriptVachar(QLatin1Char('^'))
 
-    , scriptDir(QLatin1String("LC_SCRIPTS"))
+    , scriptDir(QStringLiteral("LC_SCRIPTS"))
     , scriptModules()
     , scriptModulesToLoad()
 
@@ -383,24 +395,21 @@ void KLocalizedStringPrivate::translateRaw(const QByteArray &domain,
     // Empty msgid would result in returning the catalog header,
     // which is never intended, so warn and return empty translation.
     if (msgid.isNull() || msgid.isEmpty()) {
-        qWarning() << QString::fromLatin1(
-                       "KLocalizedString: "
-                       "Trying to look up translation of \"\", fix the code.");
+        qWarning() <<  "KLocalizedString: "
+                       "Trying to look up translation of \"\", fix the code.";
         language.clear();
         msgstr.clear();
         return;
     }
     // Gettext semantics allows empty context, but it is pointless, so warn.
     if (!msgctxt.isNull() && msgctxt.isEmpty()) {
-        qWarning() << QString::fromLatin1(
-                       "KLocalizedString: "
-                       "Using \"\" as context, fix the code.");
+        qWarning() <<  "KLocalizedString: "
+                       "Using \"\" as context, fix the code.";
     }
     // Gettext semantics allows empty plural, but it is pointless, so warn.
     if (!msgid_plural.isNull() && msgid_plural.isEmpty()) {
-        qWarning() << QString::fromLatin1(
-                       "KLocalizedString: "
-                       "Using \"\" as plural text, fix the code.");
+        qWarning() <<  "KLocalizedString: "
+                       "Using \"\" as plural text, fix the code.";
     }
 
     // Set translation to text in code language, in case no translation found.
@@ -470,10 +479,9 @@ QString KLocalizedStringPrivate::toString(const QByteArray &domain,
 
     // Assure the message has been supplied.
     if (text.isEmpty()) {
-        qWarning() << QString::fromLatin1(
-                       "Trying to convert empty KLocalizedString to QString.");
+        qWarning() << "Trying to convert empty KLocalizedString to QString.";
 #ifndef NDEBUG
-        return QLatin1String("(I18N_EMPTY_MESSAGE)");
+        return QStringLiteral("(I18N_EMPTY_MESSAGE)");
 #else
         return QString();
 #endif
@@ -481,7 +489,7 @@ QString KLocalizedStringPrivate::toString(const QByteArray &domain,
 
     // Check whether plural argument has been supplied, if message has plural.
     if (!plural.isEmpty() && !numberSet) {
-        qWarning() << QString::fromLatin1(
+        qWarning() << QStringLiteral(
                        "Plural argument to message {%1} not supplied before conversion.")
                    .arg(shortenMessage(QString::fromUtf8(text)));
     }
@@ -532,7 +540,7 @@ QString KLocalizedStringPrivate::toString(const QByteArray &domain,
     } else { // fencePos == 0
         // The msgstr starts with the script fence, no ordinary translation.
         // This is not allowed, consider message not translated.
-        qWarning() << QString::fromLatin1(
+        qWarning() << QStringLiteral(
                        "Scripted message {%1} without ordinary translation, discarded.")
                    .arg(shortenMessage(translation));
         translation =   plural.isEmpty() || number == 1
@@ -556,7 +564,7 @@ QString KLocalizedStringPrivate::toString(const QByteArray &domain,
             if (markupAware && !kls.d->markupAware) {
                 resdArg = Kuit::escape(resdArg);
             }
-            resdArg = QString::fromLatin1("%1").arg(resdArg, fieldWidth, fillChar);
+            resdArg = QStringLiteral("%1").arg(resdArg, fieldWidth, fillChar);
             resolvedArguments.append(resdArg);
         } else {
             QString resdArg = arguments[i];
@@ -701,7 +709,7 @@ QString KLocalizedStringPrivate::substituteSimple(const QString &translation,
 #ifndef NDEBUG
             if (!isPartial) {
                 // spoof the message
-                finalTranslation.append(QLatin1String("(I18N_ARGUMENT_MISSING)"));
+                finalTranslation.append(QStringLiteral("(I18N_ARGUMENT_MISSING)"));
             }
 #endif
         } else { // just fine
@@ -717,7 +725,7 @@ QString KLocalizedStringPrivate::substituteSimple(const QString &translation,
         for (int i = 0; i < ords.size(); i++) {
             if (!ords.at(i)) {
                 gaps = true;
-                qWarning() << QString::fromLatin1(
+                qWarning() << QStringLiteral(
                                "Placeholder %%1 skipped in message {%2}.")
                            .arg(QString::number(i + 1), shortenMessage(translation));
             }
@@ -734,15 +742,15 @@ QString KLocalizedStringPrivate::substituteSimple(const QString &translation,
 
         // Some spoofs.
         if (gaps) {
-            finalTranslation.append(QLatin1String("(I18N_GAPS_IN_PLACEHOLDER_SEQUENCE)"));
+            finalTranslation.append(QStringLiteral("(I18N_GAPS_IN_PLACEHOLDER_SEQUENCE)"));
         }
         if (ords.size() < arguments.size()) {
-            finalTranslation.append(QLatin1String("(I18N_EXCESS_ARGUMENTS_SUPPLIED)"));
+            finalTranslation.append(QStringLiteral("(I18N_EXCESS_ARGUMENTS_SUPPLIED)"));
         }
     }
     if (!isPartial) {
         if (!plural.isEmpty() && !numberSet) {
-            finalTranslation.append(QLatin1String("(I18N_PLURAL_ARGUMENT_MISSING)"));
+            finalTranslation.append(QStringLiteral("(I18N_PLURAL_ARGUMENT_MISSING)"));
         }
     }
 #endif
@@ -858,13 +866,13 @@ int KLocalizedStringPrivate::resolveInterpolation(const QString &scriptedTransla
             ++tpos;
         }
         if (tpos == slen) {
-            qWarning() << QString::fromLatin1(
+            qWarning() << QStringLiteral(
                            "Unclosed interpolation {%1} in message {%2}.")
                        .arg(scriptedTranslation.mid(pos, tpos - pos),
                             shortenMessage(scriptedTranslation));
             return -1;
         }
-        if (scriptedTranslation.mid(tpos, ielen) == s->endInterp) {
+        if (scriptedTranslation.midRef(tpos, ielen) == s->endInterp) {
             break; // no more arguments
         }
 
@@ -891,7 +899,7 @@ int KLocalizedStringPrivate::resolveInterpolation(const QString &scriptedTransla
                     ++tpos;
                 }
                 if (tpos == slen) {
-                    qWarning() << QString::fromLatin1(
+                    qWarning() << QStringLiteral(
                                    "Unclosed quote in interpolation {%1} in message {%2}.")
                                .arg(scriptedTranslation.mid(pos, tpos - pos),
                                     shortenMessage(scriptedTranslation));
@@ -932,7 +940,7 @@ int KLocalizedStringPrivate::resolveInterpolation(const QString &scriptedTransla
                     ++tpos;
                 }
                 if (tpos == slen) {
-                    qWarning() << QString::fromLatin1(
+                    qWarning() << QStringLiteral(
                                    "Non-terminated interpolation {%1} in message {%2}.")
                                .arg(scriptedTranslation.mid(pos, tpos - pos),
                                     shortenMessage(scriptedTranslation));
@@ -987,7 +995,7 @@ int KLocalizedStringPrivate::resolveInterpolation(const QString &scriptedTransla
     if (!scriptError.isEmpty()) { // problem with evaluation
         fallback = true; // also signal fallback
         if (!scriptError.isEmpty()) {
-            qWarning() << QString::fromLatin1(
+            qWarning() << QStringLiteral(
                            "Interpolation {%1} in {%2} failed: %3")
                        .arg(scriptedTranslation.mid(pos, tpos - pos),
                             shortenMessage(scriptedTranslation),
@@ -1006,14 +1014,14 @@ QVariant KLocalizedStringPrivate::segmentToValue(const QString &segment) const
     // value reference, or the reference is out of bounds.
 
     // Value reference must start with a special character.
-    if (segment.left(1) != s->scriptVachar) {
+    if (!segment.startsWith(s->scriptVachar)) {
         return QVariant();
     }
 
     // Reference number must start with 1-9.
     // (If numstr is empty, toInt() will return 0.)
     QString numstr = segment.mid(1);
-    if (numstr.left(1).toInt() < 1) {
+    if (numstr.leftRef(1).toInt() < 1) {
         return QVariant();
     }
 
@@ -1059,7 +1067,7 @@ QString KLocalizedStringPrivate::postTranscript(const QString &pcall,
 
     // If the evaluation went wrong.
     if (!scriptError.isEmpty()) {
-        qWarning() << QString::fromLatin1(
+        qWarning() << QStringLiteral(
                        "Post call {%1} for message {%2} failed: %3")
                    .arg(pcall, shortenMessage(msgid), scriptError);
         return QString();
@@ -1093,12 +1101,8 @@ KLocalizedString KLocalizedString::subs(int a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(abs(a));
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(std::abs(a));
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<intn>(a));
     return kls;
 }
@@ -1107,12 +1111,8 @@ KLocalizedString KLocalizedString::subs(uint a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(a);
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(a);
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<uintn>(a));
     return kls;
 }
@@ -1121,12 +1121,8 @@ KLocalizedString KLocalizedString::subs(long a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(abs(a));
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(std::abs(a));
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<intn>(a));
     return kls;
 }
@@ -1135,12 +1131,8 @@ KLocalizedString KLocalizedString::subs(ulong a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(a);
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(a);
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<uintn>(a));
     return kls;
 }
@@ -1149,12 +1141,8 @@ KLocalizedString KLocalizedString::subs(qlonglong a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(qAbs(a));
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(qAbs(a));
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<intn>(a));
     return kls;
 }
@@ -1163,12 +1151,8 @@ KLocalizedString KLocalizedString::subs(qulonglong a, int fieldWidth, int base,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    if (!kls.d->plural.isEmpty() && !kls.d->numberSet) {
-        kls.d->number = static_cast<pluraln>(a);
-        kls.d->numberSet = true;
-        kls.d->numberOrdinal = d->arguments.size();
-    }
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, base, fillChar));
+    kls.d->checkNumber(a);
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, base, fillChar));
     kls.d->values.append(static_cast<uintn>(a));
     return kls;
 }
@@ -1178,7 +1162,7 @@ KLocalizedString KLocalizedString::subs(double a, int fieldWidth,
                                         QChar fillChar) const
 {
     KLocalizedString kls(*this);
-    kls.d->arguments.append(QString::fromLatin1("%1").arg(a, fieldWidth, format, precision, fillChar));
+    kls.d->arguments.append(QStringLiteral("%1").arg(a, fieldWidth, format, precision, fillChar));
     kls.d->values.append(static_cast<realn>(a));
     return kls;
 }
@@ -1188,7 +1172,7 @@ KLocalizedString KLocalizedString::subs(QChar a, int fieldWidth,
 {
     KLocalizedString kls(*this);
     QString baseArg = QString(a);
-    QString fmtdArg = QString::fromLatin1("%1").arg(a, fieldWidth, fillChar);
+    QString fmtdArg = QStringLiteral("%1").arg(a, fieldWidth, fillChar);
     kls.d->arguments.append(fmtdArg);
     kls.d->values.append(baseArg);
     return kls;
@@ -1199,7 +1183,7 @@ KLocalizedString KLocalizedString::subs(const QString &a, int fieldWidth,
 {
     KLocalizedString kls(*this);
     QString baseArg = a;
-    QString fmtdArg = QString::fromLatin1("%1").arg(a, fieldWidth, fillChar);
+    QString fmtdArg = QStringLiteral("%1").arg(a, fieldWidth, fillChar);
     kls.d->arguments.append(fmtdArg);
     kls.d->values.append(baseArg);
     return kls;
@@ -1289,10 +1273,24 @@ QSet<QString> KLocalizedString::availableApplicationTranslations()
 {
     KLocalizedStringPrivateStatics *s = staticsKLSP();
     QSet<QString> availableLanguages;
-    if (!s->applicationDomain.isEmpty()) {
-        availableLanguages = KCatalog::availableCatalogLanguages(s->applicationDomain);
+    QByteArray domain = s->applicationDomain;
+    if (!domain.isEmpty()) {
+        availableLanguages = KCatalog::availableCatalogLanguages(domain);
         availableLanguages.insert(s->codeLanguage);
     }
+
+    return availableLanguages;
+}
+
+QSet<QString> KLocalizedString::availableDomainTranslations(const QByteArray &domain)
+{
+    QSet<QString> availableLanguages;
+
+    if (!domain.isEmpty()) {
+        availableLanguages = KCatalog::availableCatalogLanguages(domain);
+        availableLanguages.insert(staticsKLSP()->codeLanguage);
+    }
+
     return availableLanguages;
 }
 
@@ -1362,32 +1360,16 @@ void KLocalizedStringPrivate::loadTranscript()
     s->loadTranscriptCalled = true;
     s->ktrs = NULL; // null indicates that Transcript is not available
 
-#if 0
-    // FIXME: Automatic plugin path resolution does not work at the moment,
-    // so search manually through library paths.
-    QString pluginPathNoExt = QLatin1String("kf5/ktranscript");
-#else
-    QString pluginPathNoExt;
-    QStringList nameFilters;
-    QString pluginSubdir = QLatin1String("kf5");
-    QString pluginName = QLatin1String("ktranscript");
-    nameFilters.append(pluginName + QLatin1String(".*"));
-    foreach (const QString &dirPath, QCoreApplication::libraryPaths()) {
-        QString dirPathKf = dirPath + QLatin1Char('/') + pluginSubdir;
-        if (!QDir(dirPathKf).entryList(nameFilters).isEmpty()) {
-            pluginPathNoExt = dirPathKf + QLatin1Char('/') + pluginName;
-            break;
-        }
-    }
-    if (pluginPathNoExt.isEmpty()) {
-        qWarning() << QString::fromLatin1("Cannot find Transcript plugin.");
+    // QPluginLoader is just used to find the plugin
+    QPluginLoader loader(QStringLiteral("kf5/ktranscript"));
+    if (loader.fileName().isEmpty()) {
+        qWarning() << "Cannot find Transcript plugin.";
         return;
     }
-#endif
 
-    QLibrary lib(pluginPathNoExt);
+    QLibrary lib(loader.fileName());
     if (!lib.load()) {
-        qWarning() << QString::fromLatin1("Cannot load Transcript plugin:")
+        qWarning() << "Cannot load Transcript plugin:"
                    << lib.errorString();
         return;
     }
@@ -1395,8 +1377,7 @@ void KLocalizedStringPrivate::loadTranscript()
     InitFunc initf = (InitFunc) lib.resolve("load_transcript");
     if (!initf) {
         lib.unload();
-        qWarning() << QString::fromLatin1(
-                       "Cannot find function load_transcript in Transcript plugin.");
+        qWarning() << "Cannot find function load_transcript in Transcript plugin.";
         return;
     }
 
@@ -1473,9 +1454,8 @@ QString KLocalizedString::translateQt(const char *context,
     QMutexLocker lock(&s->klspMutex);
 
     if (!sourceText || !sourceText[0]) {
-        qWarning() << QString::fromLatin1(
-                       "KLocalizedString::translateQt: "
-                       "Trying to look up translation of \"\", fix the code.");
+        qWarning() <<  "KLocalizedString::translateQt: "
+                       "Trying to look up translation of \"\", fix the code.";
         return QString();
     }
 
